/*
** Job Arranger for ZABBIX
** Copyright (C) 2012 FitechForce, Inc. All Rights Reserved.
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/

/*
** $Date:: 2013-01-17 13:32:40 +0900 #$
** $Revision: 3582 $
** $Author: ossinfra@FITECHLABS.CO.JP $
**/

#include "common.h"
#include "comms.h"
#include "db.h"
#include "log.h"

#include "jacommon.h"
#include "jaconnect.h"

/******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *                                                                            *
 * Purpose:                                                                   *
 *                                                                            *
 * Parameters:                                                                *
 *                                                                            *
 * Return value:                                                              *
 *                                                                            *
 * Comments:                                                                  *
 *                                                                            *
 ******************************************************************************/
int ja_connect(zbx_sock_t * s, const zbx_uint64_t inner_job_id,
               const int host_flag, const char *host_name)
{
    int ret;
    DB_RESULT result;
    DB_ROW row;
    char *host_name_esc;
    zbx_uint64_t hostid;
    char *host;
    int port;
    const char *__function_name = "ja_connect";

    zabbix_log(LOG_LEVEL_DEBUG,
               "In %s() inner_job_id: " ZBX_FS_UI64
               ", host_flag: %d, host_name: %s", __function_name,
               inner_job_id, host_flag, host_name);

    ret = FAIL;
    result = NULL;
    host = NULL;
    port = CONFIG_AGENT_LISTEN_PORT;
    host_name_esc = DBdyn_escape_string(host_name);

    if (host_flag == 1) {
        result =
            DBselect
            ("select before_value from ja_run_value_before_table where inner_job_id = "
             ZBX_FS_UI64 " and value_name = '%s'", inner_job_id,
             host_name_esc);
        row = DBfetch(result);
        if (row == NULL) {
            zabbix_log(LOG_LEVEL_ERR,
                       "In %s() can not find host name from ja_run_value_before_table. value_name: %s",
                       __function_name, host_name_esc);
            goto error;
        }
        zbx_free(host_name_esc);
        host_name_esc = DBdyn_escape_string(row[0]);
        DBfree_result(result);
    }

    result =
        DBselect
        ("select hostid, useip, dns, ip from hosts where host = '%s'",
         host_name_esc);
    row = DBfetch(result);
    if (row == NULL) {
        zabbix_log(LOG_LEVEL_ERR,
                   "In %s() can not find host from hosts. host: %s",
                   host_name_esc);
        goto error;
    }
    ZBX_STR2UINT64(hostid, row[0]);
    if (atoi(row[1]) == 0) {
        // use dns
        host = zbx_dsprintf(host, "%s", row[2]);
    } else {
        // use ip
        host = zbx_dsprintf(host, "%s", row[3]);
    }
    DBfree_result(result);

    result =
        DBselect("select value from hostmacro where hostid = " ZBX_FS_UI64
                 " and macro = '%s'", hostid, JA_AGENT_PORT);
    row = DBfetch(result);
    if (row != NULL)
        port = atoi(row[0]);
    DBfree_result(result);
    result = NULL;

    zabbix_log(LOG_LEVEL_DEBUG,
               "In %s() connect source_ip: %s, host: %s, port: %d, timeout: %d",
               __function_name, CONFIG_SOURCE_IP, host, port,
               CONFIG_TIMEOUT);
    ret = zbx_tcp_connect(s, CONFIG_SOURCE_IP, host, port, CONFIG_TIMEOUT);
    if (ret == FAIL)
        zabbix_log(LOG_LEVEL_ERR, "connect error: %s", zbx_tcp_strerror());

  error:
    if (host_name_esc != NULL)
        zbx_free(host_name_esc);
    if (host != NULL)
        zbx_free(host);
    if (result != NULL)
        DBfree_result(result);
    return ret;
}
