/*
** Job Arranger for ZABBIX
** Copyright (C) 2012 FitechForce, Inc. All Rights Reserved.
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/

/*
** $Date:: 2013-02-25 11:36:44 +0900 #$
** $Revision: 3826 $
** $Author: ossinfra@FITECHLABS.CO.JP $
**/

#include "common.h"
#include "log.h"
#include "db.h"

#include "jacommon.h"
#include "jadb.h"
#include "javalue.h"
/******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *                                                                            *
 * Purpose:                                                                   *
 *                                                                            *
 * Parameters:                                                                *
 *                                                                            *
 * Return value:                                                              *
 *                                                                            *
 * Comments:                                                                  *
 *                                                                            *
 ******************************************************************************/
int ja_set_value_before(const zbx_uint64_t inner_job_id,
                        const zbx_uint64_t inner_jobnet_id,
                        const char *value_name, const char *before_value)
{
    int ret, db_ret;
    char *value_name_esc, *before_value_esc;
    char value[JA_MAX_DATA_LEN];
    const char *__function_name = "ja_set_value_before";

    zabbix_log(LOG_LEVEL_DEBUG,
               "In %s() inner_job_id: " ZBX_FS_UI64 ", inner_jobnet_id: "
               ZBX_FS_UI64, __function_name, inner_job_id,
               inner_jobnet_id);

    if (inner_job_id <= 0 || inner_jobnet_id <= 0 || value_name == NULL)
        return FAIL;
    ret = SUCCEED;
    value_name_esc = DBdyn_escape_string(value_name);
    if (before_value == NULL) {
        before_value_esc = DBdyn_escape_string("");
    } else {
        before_value_esc = DBdyn_escape_string(before_value);
    }

    if (ja_get_value_before(inner_job_id, value_name, value) == SUCCEED) {
        db_ret =
            DBexecute
            ("update ja_run_value_before_table set inner_jobnet_id = "
             ZBX_FS_UI64 ", before_value = '%s' where inner_job_id = "
             ZBX_FS_UI64 " and value_name = '%s'", inner_jobnet_id,
             before_value_esc, inner_job_id, value_name_esc);
    } else {
        db_ret =
            DBexecute("insert into ja_run_value_before_table values ("
                      ZBX_FS_UI64 ", " ZBX_FS_UI64 ", '%s', '%s')",
                      inner_job_id, inner_jobnet_id, value_name_esc,
                      before_value_esc);
    }

    if (ZBX_DB_OK > db_ret) {
        ja_log("JAVALUE300001", inner_jobnet_id, NULL, __function_name,
               inner_job_id, inner_jobnet_id);
        ret = FAIL;
    }

    zbx_free(value_name_esc);
    zbx_free(before_value_esc);
    return ret;
}

/******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *                                                                            *
 * Purpose:                                                                   *
 *                                                                            *
 * Parameters:                                                                *
 *                                                                            *
 * Return value:                                                              *
 *                                                                            *
 * Comments:                                                                  *
 *                                                                            *
 ******************************************************************************/
int ja_set_value_after(const zbx_uint64_t inner_job_id,
                       const zbx_uint64_t inner_jobnet_id,
                       const char *value_name, const char *after_value)
{
    int ret, db_ret;
    char *value_name_esc, *after_value_esc;
    char value[JA_MAX_DATA_LEN];
    const char *__function_name = "ja_set_value_after";

    zabbix_log(LOG_LEVEL_DEBUG,
               "In %s() inner_job_id: " ZBX_FS_UI64 ", inner_jobnet_id: "
               ZBX_FS_UI64, __function_name, inner_job_id,
               inner_jobnet_id);

    if (inner_job_id <= 0 || inner_jobnet_id <= 0 || value_name == NULL)
        return FAIL;
    ret = SUCCEED;
    value_name_esc = DBdyn_escape_string(value_name);
    if (after_value == NULL) {
        after_value_esc = DBdyn_escape_string("");
    } else {
        after_value_esc = DBdyn_escape_string(after_value);
    }

    if (ja_get_value_after(inner_job_id, value_name, value) == SUCCEED) {
        db_ret =
            DBexecute
            ("update ja_run_value_after_table set inner_jobnet_id = "
             ZBX_FS_UI64 ",  after_value = '%s' where inner_job_id = "
             ZBX_FS_UI64 " and value_name = '%s'", inner_jobnet_id,
             after_value_esc, inner_job_id, value_name_esc);
    } else {
        db_ret =
            DBexecute("insert into ja_run_value_after_table values ("
                      ZBX_FS_UI64 ", " ZBX_FS_UI64 ", '%s', '%s')",
                      inner_job_id, inner_jobnet_id, value_name_esc,
                      after_value_esc);
    }

    if (ZBX_DB_OK > db_ret) {
        ja_log("JAVALUE300001", inner_jobnet_id, NULL, __function_name,
               inner_job_id, inner_jobnet_id);
        ret = FAIL;
    }

    zbx_free(value_name_esc);
    zbx_free(after_value_esc);
    return ret;
}

/******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *                                                                            *
 * Purpose:                                                                   *
 *                                                                            *
 * Parameters:                                                                *
 *                                                                            *
 * Return value:                                                              *
 *                                                                            *
 * Comments:                                                                  *
 *                                                                            *
 ******************************************************************************/
int ja_get_value_before(const zbx_uint64_t inner_job_id,
                        const char *value_name, char *before_value)
{
    int ret;
    DB_RESULT result;
    DB_ROW row;
    char *value_name_esc;
    const char *__function_name = "ja_get_value_before";

    zabbix_log(LOG_LEVEL_DEBUG,
               "In %s() inner_job_id: " ZBX_FS_UI64, __function_name,
               inner_job_id);

    if (value_name == NULL)
        return FAIL;
    ret = SUCCEED;
    value_name_esc = DBdyn_escape_string(value_name);
    result =
        DBselect
        ("select before_value from ja_run_value_before_table "
         " where inner_job_id = " ZBX_FS_UI64 " and value_name = '%s'",
         inner_job_id, value_name_esc);
    row = DBfetch(result);
    if (row == NULL) {
        ret = FAIL;
    } else {
        if (row[0] == NULL)
            ret = FAIL;
        else
            zbx_snprintf(before_value, strlen(row[0]), "%s", row[0]);
    }
    DBfree_result(result);
    zbx_free(value_name_esc);

    return ret;
}

/******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *                                                                            *
 * Purpose:                                                                   *
 *                                                                            *
 * Parameters:                                                                *
 *                                                                            *
 * Return value:                                                              *
 *                                                                            *
 * Comments:                                                                  *
 *                                                                            *
 ******************************************************************************/
int ja_get_value_after(const zbx_uint64_t inner_job_id,
                       const char *value_name, char *after_value)
{
    int ret;
    DB_RESULT result;
    DB_ROW row;
    char *value_name_esc;
    const char *__function_name = "ja_get_value_after";

    zabbix_log(LOG_LEVEL_DEBUG,
               "In %s() inner_job_id: " ZBX_FS_UI64, __function_name,
               inner_job_id);

    if (value_name == NULL)
        return FAIL;
    ret = SUCCEED;
    value_name_esc = DBdyn_escape_string(value_name);
    result =
        DBselect
        ("select after_value from ja_run_value_after_table "
         " where inner_job_id = " ZBX_FS_UI64 " and value_name = '%s'",
         inner_job_id, value_name_esc);
    row = DBfetch(result);
    if (row == NULL) {
        ret = FAIL;
    } else {
        if (row[0] == NULL)
            ret = FAIL;
        else
            zbx_snprintf(after_value, strlen(row[0]), "%s", row[0]);
    }
    DBfree_result(result);
    zbx_free(value_name_esc);

    return ret;
}

/******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *                                                                            *
 * Purpose:                                                                   *
 *                                                                            *
 * Parameters:                                                                *
 *                                                                            *
 * Return value:                                                              *
 *                                                                            *
 * Comments:                                                                  *
 *                                                                            *
 ******************************************************************************/
int ja_value_before_after(const zbx_uint64_t before_inner_job_id,
                          const zbx_uint64_t after_inner_job_id,
                          const zbx_uint64_t inner_jobnet_id)
{
    int ret, db_ret;
    DB_RESULT before_result;
    DB_ROW before_row;
    DB_RESULT after_result;
    DB_ROW after_row;
    int cmp, find;
    char *value_name, *before_value;
    char *value_name_esc, *before_value_esc;
    zbx_uint64_t after_inner_jobnet_id;
    const char *__function_name = "ja_value_before_after";

    zabbix_log(LOG_LEVEL_DEBUG,
               "In %s() before_inner_job_id: " ZBX_FS_UI64
               ", after_inner_job_id: " ZBX_FS_UI64, __function_name,
               before_inner_job_id, after_inner_job_id);

    ret = SUCCEED;
    after_inner_jobnet_id = inner_jobnet_id;
    before_result =
        DBselect
        ("select inner_jobnet_id, value_name, before_value from ja_run_value_before_table"
         " where inner_job_id = " ZBX_FS_UI64 " order by value_name",
         before_inner_job_id);
    after_result =
        DBselect("select value_name from ja_run_value_after_table"
                 " where inner_job_id = " ZBX_FS_UI64
                 " order by value_name", after_inner_job_id);

    while (NULL != (before_row = DBfetch(before_result))) {
        if (after_inner_jobnet_id == 0)
            ZBX_STR2UINT64(after_inner_jobnet_id, before_row[0]);
        value_name = before_row[1];
        before_value = before_row[2];
        value_name_esc = DBdyn_escape_string(value_name);
        if (before_value == NULL) {
            before_value_esc = DBdyn_escape_string("");
        } else {
            before_value_esc = DBdyn_escape_string(before_value);
        }

        find = 0;
        ja_db_data_head(after_result);
        while (NULL != (after_row = DBfetch(after_result))) {
            cmp = strcmp(after_row[0], value_name);
            if (cmp < 0) {
                continue;
            } else if (cmp == 0) {
                find = 1;
                break;
            } else {
                break;
            }
        }
        if (find == 0) {
            db_ret =
                DBexecute("insert into ja_run_value_after_table values ("
                          ZBX_FS_UI64 ", " ZBX_FS_UI64 ", '%s', '%s')",
                          after_inner_job_id, after_inner_jobnet_id,
                          value_name_esc, before_value_esc);
        } else {
            db_ret =
                DBexecute
                ("update ja_run_value_after_table set inner_jobnet_id = "
                 ZBX_FS_UI64 ",  after_value = '%s' where inner_job_id = "
                 ZBX_FS_UI64 " and value_name = '%s'",
                 after_inner_jobnet_id, before_value_esc,
                 after_inner_job_id, value_name_esc);
        }
        zbx_free(value_name_esc);
        zbx_free(before_value_esc);
        if (ZBX_DB_OK > db_ret) {
            ja_log("JAVALUE300003", inner_jobnet_id, NULL, __function_name,
                   after_inner_job_id, after_inner_jobnet_id, value_name);
            ret = FAIL;
            break;
        }
    }
    DBfree_result(before_result);
    DBfree_result(after_result);

    return ret;
}

/******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *                                                                            *
 * Purpose:                                                                   *
 *                                                                            *
 * Parameters:                                                                *
 *                                                                            *
 * Return value:                                                              *
 *                                                                            *
 * Comments:                                                                  *
 *                                                                            *
 ******************************************************************************/
int ja_value_after_before(const zbx_uint64_t after_inner_job_id,
                          const zbx_uint64_t before_inner_job_id,
                          const zbx_uint64_t inner_jobnet_id)
{
    int ret, db_ret;
    DB_RESULT after_result;
    DB_ROW after_row;
    DB_RESULT before_result;
    DB_ROW before_row;
    int cmp, find;
    char *value_name, *after_value;
    char *value_name_esc, *after_value_esc;
    zbx_uint64_t before_inner_jobnet_id;
    const char *__function_name = "ja_value_after_before";

    zabbix_log(LOG_LEVEL_DEBUG,
               "In %s() after_inner_job_id: " ZBX_FS_UI64
               ", before_inner_job_id: " ZBX_FS_UI64, __function_name,
               after_inner_job_id, before_inner_job_id);

    ret = SUCCEED;
    before_inner_jobnet_id = inner_jobnet_id;
    after_result =
        DBselect
        ("select inner_jobnet_id, value_name, after_value from ja_run_value_after_table"
         " where inner_job_id = " ZBX_FS_UI64 " order by value_name",
         after_inner_job_id);
    before_result =
        DBselect("select value_name from ja_run_value_before_table"
                 " where inner_job_id = " ZBX_FS_UI64
                 " order by value_name", before_inner_job_id);

    while (NULL != (after_row = DBfetch(after_result))) {
        if (before_inner_jobnet_id == 0)
            ZBX_STR2UINT64(before_inner_jobnet_id, after_row[0]);
        value_name = after_row[1];
        after_value = after_row[2];
        value_name_esc = DBdyn_escape_string(value_name);
        if (after_value == NULL) {
            after_value_esc = DBdyn_escape_string("");
        } else {
            after_value_esc = DBdyn_escape_string(after_value);
        }

        find = 0;
        ja_db_data_head(before_result);
        while (NULL != (before_row = DBfetch(before_result))) {
            cmp = strcmp(before_row[0], value_name);
            if (cmp < 0) {
                continue;
            } else if (cmp == 0) {
                find = 1;
                break;
            } else {
                break;
            }
        }
        if (find == 0) {
            db_ret =
                DBexecute("insert into ja_run_value_before_table values ("
                          ZBX_FS_UI64 ", " ZBX_FS_UI64 ", '%s', '%s')",
                          before_inner_job_id, before_inner_jobnet_id,
                          value_name_esc, after_value_esc);
        } else {
            db_ret =
                DBexecute
                ("update ja_run_value_before_table set inner_jobnet_id = "
                 ZBX_FS_UI64 ",  before_value = '%s' where inner_job_id = "
                 ZBX_FS_UI64 " and value_name = '%s'",
                 before_inner_jobnet_id, after_value_esc,
                 before_inner_job_id, value_name_esc);
        }
        zbx_free(value_name_esc);
        zbx_free(after_value_esc);
        if (ZBX_DB_OK > db_ret) {
            ja_log("JAVALUE300003", inner_jobnet_id, NULL, __function_name,
                   before_inner_job_id, before_inner_jobnet_id,
                   value_name);
            ret = FAIL;
            break;
        }
    }
    DBfree_result(after_result);
    DBfree_result(before_result);

    return ret;
}

/******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *                                                                            *
 * Purpose:                                                                   *
 *                                                                            *
 * Parameters:                                                                *
 *                                                                            *
 * Return value:                                                              *
 *                                                                            *
 * Comments:                                                                  *
 *                                                                            *
 ******************************************************************************/
int ja_value_before_jobnet_in(const zbx_uint64_t inner_job_id,
                              const zbx_uint64_t inner_jobnet_id)
{
    int ret, db_ret;
    DB_RESULT result;
    DB_ROW row;
    char *value_name, *before_value;
    char *value_name_esc, *before_value_esc;
    const char *__function_name = "ja_value_before_jobnet_in";

    zabbix_log(LOG_LEVEL_DEBUG,
               "In %s() inner_job_id: " ZBX_FS_UI64 ", inner_jobnet_id: "
               ZBX_FS_UI64, __function_name, inner_job_id,
               inner_jobnet_id);

    ret = SUCCEED;
    result =
        DBselect
        ("select value_name, before_value from ja_run_value_before_table"
         " where inner_job_id = " ZBX_FS_UI64, inner_job_id);
    while (NULL != (row = DBfetch(result))) {
        value_name = row[0];
        before_value = row[1];
        value_name_esc = DBdyn_escape_string(value_name);
        before_value_esc = DBdyn_escape_string(before_value);
        db_ret =
            DBexecute("insert into ja_value_before_jobnet_table values ("
                      ZBX_FS_UI64 ", '%s', '%s')", inner_jobnet_id,
                      value_name_esc, before_value_esc);
        zbx_free(value_name_esc);
        zbx_free(before_value_esc);
        if (ZBX_DB_OK > db_ret) {
            zabbix_log(LOG_LEVEL_ERR,
                       "In %s() inner_jobnet_id: " ZBX_FS_UI64
                       ", inner_job_id: " ZBX_FS_UI64
                       ", value_name: %s, before_value: %s",
                       __function_name, inner_jobnet_id, inner_job_id,
                       value_name, before_value);
            ret = FAIL;
            break;
        }
    }

    DBfree_result(result);
    return ret;
}

/******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *                                                                            *
 * Purpose:                                                                   *
 *                                                                            *
 * Parameters:                                                                *
 *                                                                            *
 * Return value:                                                              *
 *                                                                            *
 * Comments:                                                                  *
 *                                                                            *
 ******************************************************************************/
int ja_value_before_jobnet_out(const zbx_uint64_t inner_jobnet_id,
                               const zbx_uint64_t inner_job_id)
{
    int ret, db_ret;
    DB_RESULT result;
    DB_ROW row;
    char *value_name, *before_value;
    char *value_name_esc, *before_value_esc;
    const char *__function_name = "ja_value_before_jobnet_out";

    zabbix_log(LOG_LEVEL_DEBUG,
               "In %s() inner_jobnet_id: " ZBX_FS_UI64 ", inner_job_id: "
               ZBX_FS_UI64, __function_name, inner_jobnet_id,
               inner_job_id);

    ret = SUCCEED;
    result =
        DBselect
        ("select value_name, before_value from ja_value_before_jobnet_table"
         " where inner_jobnet_id = " ZBX_FS_UI64, inner_jobnet_id);
    while (NULL != (row = DBfetch(result))) {
        value_name = row[0];
        before_value = row[1];
        value_name_esc = DBdyn_escape_string(value_name);
        before_value_esc = DBdyn_escape_string(before_value);
        db_ret =
            DBexecute("insert into ja_run_value_before_table values ("
                      ZBX_FS_UI64 ", " ZBX_FS_UI64 ", '%s', '%s')",
                      inner_job_id, inner_jobnet_id, value_name_esc,
                      before_value_esc);
        zbx_free(value_name_esc);
        zbx_free(before_value_esc);
        if (ZBX_DB_OK > db_ret) {
            zabbix_log(LOG_LEVEL_ERR,
                       "In %s() inner_jobnet_id: " ZBX_FS_UI64
                       ", inner_job_id: " ZBX_FS_UI64
                       ", value_name: %s, before_value: %s",
                       __function_name, inner_jobnet_id, inner_job_id,
                       value_name, before_value);
            ret = FAIL;
            break;
        }
    }

    DBfree_result(result);
    return ret;
}

/******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *                                                                            *
 * Purpose:                                                                   *
 *                                                                            *
 * Parameters:                                                                *
 *                                                                            *
 * Return value:                                                              *
 *                                                                            *
 * Comments:                                                                  *
 *                                                                            *
 ******************************************************************************/
int ja_value_after_jobnet_in(const zbx_uint64_t inner_job_id,
                             const zbx_uint64_t inner_jobnet_id)
{
    int ret, db_ret;
    DB_RESULT result;
    DB_ROW row;
    char *value_name, *after_value;
    char *value_name_esc, *after_value_esc;
    const char *__function_name = "ja_value_after_jobnet_in";

    zabbix_log(LOG_LEVEL_DEBUG,
               "In %s() inner_job_id: " ZBX_FS_UI64 ", inner_jobnet_id: "
               ZBX_FS_UI64, __function_name, inner_job_id,
               inner_jobnet_id);

    ret = SUCCEED;
    result =
        DBselect
        ("select value_name, after_value from ja_run_value_after_table"
         " where inner_job_id = " ZBX_FS_UI64, inner_job_id);
    while (NULL != (row = DBfetch(result))) {
        value_name = row[0];
        after_value = row[1];
        value_name_esc = DBdyn_escape_string(value_name);
        after_value_esc = DBdyn_escape_string(after_value);
        db_ret =
            DBexecute("insert into ja_value_after_jobnet_table values ("
                      ZBX_FS_UI64 ", '%s', '%s')", inner_jobnet_id,
                      value_name_esc, after_value_esc);
        zbx_free(value_name_esc);
        zbx_free(after_value_esc);
        if (ZBX_DB_OK > db_ret) {
            zabbix_log(LOG_LEVEL_ERR,
                       "In %s() inner_jobnet_id: " ZBX_FS_UI64
                       ", inner_job_id: " ZBX_FS_UI64
                       ", value_name: %s, after_value: %s",
                       __function_name, inner_jobnet_id, inner_job_id,
                       value_name, after_value);
            ret = FAIL;
            break;
        }
    }

    DBfree_result(result);
    return ret;
}

/******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *                                                                            *
 * Purpose:                                                                   *
 *                                                                            *
 * Parameters:                                                                *
 *                                                                            *
 * Return value:                                                              *
 *                                                                            *
 * Comments:                                                                  *
 *                                                                            *
 ******************************************************************************/
int ja_value_after_jobnet_out(const zbx_uint64_t inner_jobnet_id,
                              const zbx_uint64_t inner_job_id,
                              const zbx_uint64_t icon_inner_jobnet_id)
{
    int ret, db_ret;
    DB_RESULT result;
    DB_ROW row;
    char *value_name, *after_value;
    char *value_name_esc, *after_value_esc;
    const char *__function_name = "ja_value_after_jobnet_out";

    zabbix_log(LOG_LEVEL_DEBUG,
               "In %s() inner_jobnet_id: " ZBX_FS_UI64 ", inner_job_id: "
               ZBX_FS_UI64, __function_name, inner_jobnet_id,
               inner_job_id);

    ret = SUCCEED;
    result =
        DBselect
        ("select value_name, after_value from ja_value_after_jobnet_table"
         " where inner_jobnet_id = " ZBX_FS_UI64, inner_jobnet_id);
    while (NULL != (row = DBfetch(result))) {
        value_name = row[0];
        after_value = row[1];
        value_name_esc = DBdyn_escape_string(value_name);
        after_value_esc = DBdyn_escape_string(after_value);
        db_ret =
            DBexecute("insert into ja_run_value_after_table values ("
                      ZBX_FS_UI64 ", " ZBX_FS_UI64 ", '%s', '%s')",
                      inner_job_id, icon_inner_jobnet_id, value_name_esc,
                      after_value_esc);
        zbx_free(value_name_esc);
        zbx_free(after_value_esc);
        if (ZBX_DB_OK > db_ret) {
            zabbix_log(LOG_LEVEL_ERR,
                       "In %s() inner_jobnet_id: " ZBX_FS_UI64
                       ", inner_job_id: " ZBX_FS_UI64
                       ", value_name: %s, after_value: %s",
                       __function_name, icon_inner_jobnet_id, inner_job_id,
                       value_name, after_value);
            ret = FAIL;
            break;
        }
    }

    DBfree_result(result);
    return ret;
}

/******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *                                                                            *
 * Purpose:                                                                   *
 *                                                                            *
 * Parameters:                                                                *
 *                                                                            *
 * Return value:                                                              *
 *                                                                            *
 * Comments:                                                                  *
 *                                                                            *
 ******************************************************************************/
int ja_remove_value_after(const zbx_uint64_t inner_job_id,
                          const char *value_name)
{
    int db_ret;
    char *value_name_esc;
    const char *__function_name = "ja_remove_value_after";

    zabbix_log(LOG_LEVEL_DEBUG,
               "In %s() inner_job_id: " ZBX_FS_UI64, __function_name,
               inner_job_id);

    if (value_name == NULL)
        return FAIL;
    value_name_esc = DBdyn_escape_string(value_name);
    db_ret =
        DBexecute
        ("delete from ja_run_value_after_table "
         " where inner_job_id = " ZBX_FS_UI64 " and value_name = '%s'",
         inner_job_id, value_name_esc);
    zbx_free(value_name_esc);

    if (ZBX_DB_OK > db_ret)
        return FAIL;
    return SUCCEED;
}

/******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *                                                                            *
 * Purpose:                                                                   *
 *                                                                            *
 * Parameters:                                                                *
 *                                                                            *
 * Return value:                                                              *
 *                                                                            *
 * Comments:                                                                  *
 *                                                                            *
 ******************************************************************************/
int ja_get_jobnet_summary_start(const zbx_uint64_t inner_jobnet_id,
                                char *start_time)
{
    int ret;
    DB_RESULT result;
    DB_ROW row;
    const char *__function_name = "ja_get_jobnet_summary_start";

    zabbix_log(LOG_LEVEL_DEBUG,
               "In %s() inner_jobinet_id: " ZBX_FS_UI64, __function_name,
               inner_jobnet_id);

    ret = SUCCEED;
    result =
        DBselect
        ("select start_time from ja_run_jobnet_summary_table "
         " where inner_jobnet_id = " ZBX_FS_UI64, inner_jobnet_id);
    row = DBfetch(result);
    if (row == NULL) {
        ret = FAIL;
    } else {
        if (row[0] == NULL)
            ret = FAIL;
        else
            zbx_snprintf(start_time, 16, "%s", row[0]);
    }
    DBfree_result(result);

    if (ret == FAIL) {
        ja_log("JAVALUE300002", inner_jobnet_id, NULL, __function_name,
               inner_jobnet_id);
    }
    return ret;
}
