/*
** Job Arranger for ZABBIX
** Copyright (C) 2012 FitechForce, Inc. All Rights Reserved.
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/

/*
** $Date:: 2012-11-26 13:50:56 +0900 #$
** $Revision: 2730 $
** $Author: ossinfra@FITECHLABS.CO.JP $
**/

#include <json/json.h>
#include "common.h"
#include "comms.h"
#include "log.h"
#include "db.h"

#include "jacommon.h"
#include "jastatus.h"
#include "jaflow.h"
#include "javalue.h"
#include "jarunvalue.h"
#include "jajobobject.h"
#include "jaconnect.h"
#include "jatcp.h"
#include "jathreads.h"
#include "jaruniconfwait.h"

/******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *                                                                            *
 * Purpose:                                                                   *
 *                                                                            *
 * Parameters:                                                                *
 *                                                                            *
 * Return value:                                                              *
 *                                                                            *
 * Comments:                                                                  *
 *                                                                            *
 ******************************************************************************/
int jarun_icon_fwait(const zbx_uint64_t inner_job_id, const int method)
{
    int ret;
    DB_RESULT result;
    DB_ROW row;
    int host_flag;
    char *host_name;
    zbx_sock_t sock;
    ja_job_object job, job_res;
    json_object *jp_arg;
    pid_t pid;
    const char *__function_name = "jarun_icon_fwait";

    zabbix_log(LOG_LEVEL_DEBUG, "In %s() inner_job_id: " ZBX_FS_UI64,
               __function_name, inner_job_id);

    pid = ja_fork();
    if (pid == -1) {
        zabbix_log(LOG_LEVEL_ERR,
                   "In %s() can not fork(). inner_job_id: " ZBX_FS_UI64,
                   __function_name, inner_job_id);
        return ja_set_status_job(inner_job_id, JA_JOB_STATUS_RUNERR, -1,
                                 1);
    } else if (pid != 0) {
        waitpid(pid, NULL, WNOHANG);
        return SUCCEED;
    }

    DBconnect(ZBX_DB_CONNECT_ONCE);
    ret = FAIL;
    ja_job_object_init(&job);
    ja_job_object_init(&job_res);
    sock.socket = ZBX_SOCK_ERROR;
    host_name = NULL;
    jp_arg = NULL;

    zbx_snprintf(job.kind, sizeof(job.kind), "%s", JA_PROTO_VALUE_JOBRUN);
    job.version = JA_PROTO_TELE_VERSION;
    job.jobid = inner_job_id;
    zbx_snprintf(job.serverid, sizeof(job.serverid), "%s", serverid);
    job.method = method;
    zbx_snprintf(job.type, sizeof(job.type), "%s", JA_PROTO_VALUE_FWAIT);

    result =
        DBselect
        ("select * from ja_run_icon_fwait_table where inner_job_id = "
         ZBX_FS_UI64, inner_job_id);
    if (NULL != (row = DBfetch(result))) {
        host_flag = atoi(row[2]);
        host_name = zbx_strdup(host_name, row[3]);
        jp_arg = json_object_new_string(row[4]);
        zbx_snprintf(job.argument, sizeof(job.argument), "%s",
                     json_object_to_json_string(jp_arg));
    } else {
        DBfree_result(result);
        zabbix_log(LOG_LEVEL_ERR,
                   "In %s() can not find inner_job_id: " ZBX_FS_UI64,
                   __function_name, inner_job_id);
        ja_set_status_job(inner_job_id, JA_JOB_STATUS_ENDERR, -1, 1);
        exit(0);
    }
    DBfree_result(result);

    //zabbix_log(LOG_LEVEL_INFORMATION, "%s",  json_object_to_json_string(jp_arg));
    //goto error;

    if (ja_connect(&sock, inner_job_id, host_flag, host_name) == FAIL) {
        goto error;
    }

    if (ja_tcp_send_to(&sock, &job, CONFIG_TIMEOUT) == FAIL)
        goto error;
    if (ja_tcp_recv_to(&sock, &job_res, CONFIG_TIMEOUT) == FAIL)
        goto error;
    if (job_res.result != JA_RESPONSE_SUCCEED) {
        zabbix_log(LOG_LEVEL_ERR,
                   "In %s() inner_job_id: " ZBX_FS_UI64 " message: %s",
                   __function_name, inner_job_id, job_res.message);
        goto error;
    }

    ret = SUCCEED;
  error:
    if (sock.socket >= 0)
        zbx_tcp_close(&sock);
    if (host_name != NULL)
        zbx_free(host_name);
    if (ret == SUCCEED) {
        jarun_set_value_after(inner_job_id);
        if (ja_flow(inner_job_id, JA_FLOW_TYPE_NORMAL) == FAIL)
            ja_set_enderr(inner_job_id);
    } else {
        ja_set_status_job(inner_job_id, JA_JOB_STATUS_RUNERR, -1, 1);
    }
    DBclose();
    zabbix_log(LOG_LEVEL_DEBUG, "In %s() END", __function_name);
    exit(0);
}
